# py-pdf-term

A fully-configurable terminology extraction module written in Python

## Installation

```
pip install py-pdf-term
```

You also need to install spaCy models `ja_core_news_sm` and `en_core_web_sm`, which this module depends on.

```
pip install https://github.com/explosion/spacy-models/releases/download/ja_core_news_sm-3.2.0/ja_core_news_sm-3.2.0.tar.gz
pip install https://github.com/explosion/spacy-models/releases/download/en_core_web_sm-3.2.0/en_core_web_sm-3.2.0.tar.gz
```

## Documentation

https://kumachan-mis.github.io/py-pdf-term
